#[non_exhaustive]pub enum GridError {
UnsupportedCombination {
task: GridTask,
lattice: LatticeKind,
evidence: EvidenceKind,
},
InsufficientEvidence,
InconsistentInput(String),
DegenerateGeometry,
}Expand description
User-facing failure modes for projective-grid tasks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedCombination
The requested task/lattice/evidence combination is intentionally not implemented yet.
InsufficientEvidence
There is not enough evidence to run the requested task.
InconsistentInput(String)
Input slices disagree or contain duplicate/conflicting identifiers.
DegenerateGeometry
Geometry is degenerate, for example all model or image points are collinear.