pub fn check_consistency(
request: ConsistencyRequest<'_>,
) -> Result<ConsistencyReport, GridError>Expand description
Check whether caller-supplied coordinate hypotheses are geometrically consistent under the requested lattice family.
pub fn check_consistency(
request: ConsistencyRequest<'_>,
) -> Result<ConsistencyReport, GridError>Check whether caller-supplied coordinate hypotheses are geometrically consistent under the requested lattice family.