pub struct GridHomography {
pub h_img_from_rect: Homography,
pub h_rect_from_img: Homography,
pub min_i: i32,
pub min_j: i32,
pub max_i: i32,
pub max_j: i32,
pub px_per_cell: f32,
pub rect_width: usize,
pub rect_height: usize,
}Expand description
A global homography mapping between rectified grid space and image space.
Fields
h_img_from_rect: HomographyMaps rectified coordinates to image coordinates.
h_rect_from_img: HomographyMaps image coordinates to rectified coordinates.
min_i: i32Grid bounding box (with margin) in corner index space.
min_j: i32max_i: i32max_j: i32px_per_cell: f32Rectified pixels per grid cell.
rect_width: usizeRectified image dimensions.
rect_height: usizeImplementations
Sourceimpl GridHomography
impl GridHomography
Sourcepub fn from_corners(
corners: &HashMap<GridIndex, Point2<f32>>,
px_per_cell: f32,
margin_cells: f32,
) -> Result<Self, GridRectifyError>
pub fn from_corners( corners: &HashMap<GridIndex, Point2<f32>>, px_per_cell: f32, margin_cells: f32, ) -> Result<Self, GridRectifyError>
Compute a global homography from grid corners to a rectified coordinate system.
corners: map from grid index to image position.px_per_cell: rectified pixels per grid cell.margin_cells: extra margin around the grid bounding box (in cell units).