#[non_exhaustive]pub struct GridDimensions {
pub width: usize,
pub height: usize,
}Expand description
Optional known grid dimensions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.width: usizeNumber of cells or feature positions along the first lattice axis.
height: usizeNumber of cells or feature positions along the second lattice axis.
Implementations