pub struct SquareGridHomography<F: Float = f32> {
pub h_img_from_rect: Homography<F>,
pub h_rect_from_img: Homography<F>,
pub min_i: i32,
pub min_j: i32,
pub max_i: i32,
pub max_j: i32,
pub px_per_cell: F,
pub rect_width: usize,
pub rect_height: usize,
}Expand description
A global homography mapping between rectified grid space and image space.
Fields
h_img_from_rect: Homography<F>Maps rectified coordinates to image coordinates.
h_rect_from_img: Homography<F>Maps image coordinates to rectified coordinates.
min_i: i32Minimum grid i of the bounding box (with margin), corner-index space.
min_j: i32Minimum grid j of the bounding box (with margin), corner-index space.
max_i: i32Maximum grid i of the bounding box (with margin), corner-index space.
max_j: i32Maximum grid j of the bounding box (with margin), corner-index space.
px_per_cell: FRectified pixels per grid cell.
rect_width: usizeRectified image width in pixels.
rect_height: usizeRectified image height in pixels.
Implementations
Sourceimpl<F: Float> SquareGridHomography<F>
impl<F: Float> SquareGridHomography<F>
Sourcepub fn from_corners(
corners: &HashMap<GridCoords, Point2<F>>,
px_per_cell: F,
margin_cells: F,
) -> Result<Self, GridRectifyError>
pub fn from_corners( corners: &HashMap<GridCoords, Point2<F>>, px_per_cell: F, margin_cells: F, ) -> Result<Self, GridRectifyError>
Compute a global homography from grid corners to a rectified coordinate system.
corners: map from grid index to image position.px_per_cell: rectified pixels per grid cell.margin_cells: extra margin around the grid bounding box (in cell units).
Sourcepub fn rect_to_img(&self, p_rect: Point2<F>) -> Point2<F>
pub fn rect_to_img(&self, p_rect: Point2<F>) -> Point2<F>
Map a point from rectified space to image space.
Sourcepub fn img_to_rect(&self, p_img: Point2<F>) -> Point2<F>
pub fn img_to_rect(&self, p_img: Point2<F>) -> Point2<F>
Map a point from image space to rectified space.