#[non_exhaustive]pub struct GridDetection { /* private fields */ }Expand description
Successful grid detection.
A successful value always contains a finite projective fit. Rejected input features and intermediate hypotheses belong to the diagnostics channel.
Implementations
Sourceimpl GridDetection
impl GridDetection
Sourcepub fn grid(&self) -> &LabelledGrid
pub fn grid(&self) -> &LabelledGrid
Canonical labelled grid.
Sourcepub fn fit(&self) -> &LatticeFit
pub fn fit(&self) -> &LatticeFit
Mandatory model-to-image projective fit.